============
Installation
============


Requirements
------------

 * pymad8 is developed exclusively for Python 2.7.

Installation
------------


To install pymad8, simply run ``make install`` from the root pymad8
directory.::

  cd /my/path/to/repositories/
  git clone http://bitbucket.org/jairhul/pymad8
  cd pymad8
  make install

Alternatively, run ``make develop`` from the same directory to ensure
that any local changes are picked up.
